<?php

class PostNewJob {
    private $pdo;
    
    public function __construct($pdo) {
        $this->pdo = $pdo;
    }
    
    public function createPostNewJob($job_designation_id, $job_department_id, $job_division_id, $experience_required, $location, $salary_range, $job_code, $job_description, $job_type) {
        try {
            $stmt = $this->pdo->prepare("INSERT INTO job_posts (job_designation_id, job_department_id, job_division_id, experience_required, location, salary_range, job_code, job_description, job_type) 
                                         VALUES (:job_designation_id, :job_department_id, :job_division_id, :experience_required, :location, :salary_range, :job_code, :job_description, :job_type)");
            $stmt->execute([
                ':job_designation_id' => $job_designation_id, 
                ':job_department_id' => $job_department_id,
                ':job_division_id' => $job_division_id, 
                ':experience_required' => $experience_required,
                ':location' => $location,
                ':salary_range' => $salary_range, 
                ':job_code' => $job_code, 
                ':job_description' => $job_description, 
                ':job_type' => $job_type
            ]);

            return $stmt->rowCount() == 1;
        } catch (Exception $e) {
            // Optionally log the error message: $e->getMessage();
            return $e->getMessage();
        }
    }
    
public function getAllJobs() {
    try {
          $stmt = $this->pdo->prepare("
            SELECT jp.*, 
                   jd.name AS job_designation_name,
                   jdpt.name AS job_department_name,
                   jdv.name AS job_division_name,
                   jt.name AS job_type_name
            FROM job_posts jp
            LEFT JOIN job_designations jd ON jp.job_designation_id = jd.id
            LEFT JOIN job_departments jdpt ON jp.job_department_id = jdpt.id
            LEFT JOIN job_divisions jdv ON jp.job_division_id = jdv.id
            LEFT JOIN job_type jt ON jp.job_type = jt.id
            ORDER BY jp.id DESC
        ");
        $stmt->execute();
        $results = $stmt->fetchAll(PDO::FETCH_ASSOC);

        if (empty($results)) {
            echo "No Jobs found.";
        }

        return $results;
    } catch (Exception $e) {
        echo "Error: " . $e->getMessage();
        return false;
    }
}






        
    public function updateJob($id, $job_title, $job_category, $job_type, $location, $job_description, $salary_range, $application_deadline) {    
        try {
            $stmt = $this->pdo->prepare("UPDATE job_posts 
                                         SET job_title = :job_title,
                                             job_category = :job_category,
                                             job_type = :job_type, 
                                             location = :location, 
                                             job_description = :job_description, 
                                             salary_range = :salary_range,
                                             application_deadline = :application_deadline
                                         WHERE id = :id");
            $stmt->execute([
                ':id' => $id,
                ':job_title' => $job_title,
                ':job_category' => $job_category,
                ':job_type' => $job_type,
                ':location' => $location,
                ':job_description' => $job_description,
                ':salary_range' => $salary_range,
                ':application_deadline' => $application_deadline
            ]);
            return true;
        } catch (Exception $e) {
            return false;
        }
    }        
        
    public function deleteJob($id) {
        try {
            $stmt = $this->pdo->prepare("DELETE FROM job_posts WHERE id = :id");
            $stmt->execute([':id' => $id]);
            return true;
        } catch (Exception $e) {
            return false;
        }
    }
    
    public function getAllCategories() {
        try {
            $stmt = $this->pdo->prepare("SELECT * FROM job_category");
            $stmt->execute();
            return $stmt->fetchAll(PDO::FETCH_ASSOC);
        } catch (Exception $e) {
            return false;
        }
    }
    
    public function getAllTypes() {
        try {
            $stmt = $this->pdo->prepare("SELECT * FROM job_type");
            $stmt->execute();
            return $stmt->fetchAll(PDO::FETCH_ASSOC);
        } catch (Exception $e) {
            return false;
        }
    }
}
?>
