<?php


class ViewApplications {
    private $pdo;
    
    public function __construct($pdo) {
        $this->pdo = $pdo;
    }
            
    
    
        public function getAllApplication() 
        {
            try { 
                $stmt = $this->pdo->prepare("
                    SELECT 
                        c.id, 
                        c.full_name, 
                        c.email, 
                        c.mobile, 
                        c.country, 
                        c.experience, 
                        c.resume, 
                        c.created, 
                        c.job_role_id, 
                        j.category_name, 
                        jd.name AS designation_name, 
                        jdpt.name AS department_name, 
                        jdiv.name AS division_name 
                    FROM careers c
                    LEFT JOIN job_category j ON c.job_role_id = j.id
                    LEFT JOIN job_designations jd ON j.job_designation_id = jd.id
                    LEFT JOIN job_departments jdpt ON jd.job_designation_id = jdpt.id
                    LEFT JOIN job_divisions jdiv ON jdpt.id = jdiv.job_department_id
                ");
                $stmt->execute();
                return $stmt->fetchAll(PDO::FETCH_ASSOC);
            } catch (Exception $e) {
                return false;
            }
        }


        
        
    public function deleteApplication($id){
            try {
                $stmt = $this->pdo->prepare("DELETE FROM careers WHERE id = :id");
                $stmt->execute([':id' => $id]);
                return true;
            } catch (Exception $e) {
                return false;
            }
    }
    
     
 public function fetchApplicationsGroupedByJobDesignation() {
    try {
        // Prepare the SQL statement to join careers with job_designations and group by designation name
        $stmt = $this->pdo->prepare("
            SELECT c.*, jd.name AS designation_name
            FROM careers c
            LEFT JOIN job_designations jd ON c.job_designation = jd.id
            ORDER BY jd.name, c.created
        ");
        
        // Execute the statement
        $stmt->execute();
        
        // Fetch all results as an associative array
        $applications = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        // Initialize an array to group applications by job designation
        $groupedApplications = [];
        
        foreach ($applications as $application) {
            $designationName = $application['designation_name'];
            if (!isset($groupedApplications[$designationName])) {
                $groupedApplications[$designationName] = [];
            }
            $groupedApplications[$designationName][] = $application;
        }

        // Return the grouped applications
        return $groupedApplications;
    } catch (Exception $e) {
        // Log the error message for debugging
        error_log($e->getMessage());
        // Return a generic error message
        return 'An error occurred while fetching applications.';
    }
}





}
?>